@@ -6,8 +6,8 @@
     Check Python modules and C API for coverage.  Mostly written by Josip
     Dzolonga for the Google Highly Open Participation contest.
 
-    :copyright: 2008 by Josip Dzolonga, Georg Brandl.
-    :license: BSD.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 import re
@@ -16,7 +16,7 @@ import inspect
 import cPickle as pickle
 from os import path
 
-from sphinx.builder import Builder
+from sphinx.builders import Builder
 
 
 # utility
@@ -53,17 +53,17 @@ class CoverageBuilder(Builder):
 
         self.c_ignorexps = {}
         for (name, exps) in self.config.coverage_ignore_c_items.iteritems():
-            self.c_ignorexps[name] = compile_regex_list('coverage_ignore_c_items',
-                                                        exps, self.warn)
-        self.mod_ignorexps = compile_regex_list('coverage_ignore_modules',
-                                                self.config.coverage_ignore_modules,
-                                                self.warn)
-        self.cls_ignorexps = compile_regex_list('coverage_ignore_classes',
-                                                self.config.coverage_ignore_classes,
-                                                self.warn)
-        self.fun_ignorexps = compile_regex_list('coverage_ignore_functions',
-                                                self.config.coverage_ignore_functions,
-                                                self.warn)
+            self.c_ignorexps[name] = compile_regex_list(
+                'coverage_ignore_c_items', exps, self.warn)
+        self.mod_ignorexps = compile_regex_list(
+            'coverage_ignore_modules', self.config.coverage_ignore_modules,
+            self.warn)
+        self.cls_ignorexps = compile_regex_list(
+            'coverage_ignore_classes', self.config.coverage_ignore_classes,
+            self.warn)
+        self.fun_ignorexps = compile_regex_list(
+            'coverage_ignore_functions', self.config.coverage_ignore_functions,
+            self.warn)
 
     def get_outdated_docs(self):
         return 'coverage overview'
@@ -73,13 +73,13 @@ class CoverageBuilder(Builder):
         self.build_py_coverage()
         self.write_py_coverage()
 
-        if self.c_sourcefiles:
-            self.c_undoc = {}
-            self.build_c_coverage()
-            self.write_c_coverage()
+        self.c_undoc = {}
+        self.build_c_coverage()
+        self.write_c_coverage()
 
     def build_c_coverage(self):
         # Fetch all the info from the header files
+        c_objects = self.env.domaindata['c']['objects']
         for filename in self.c_sourcefiles:
             undoc = []
             f = open(filename, 'r')
@@ -89,7 +89,7 @@ class CoverageBuilder(Builder):
                         match = regex.match(line)
                         if match:
                             name = match.groups()[0]
-                            if name not in self.env.descrefs:
+                            if name not in c_objects:
                                 for exp in self.c_ignorexps.get(key, ()):
                                     if exp.match(name):
                                         break
@@ -117,7 +117,10 @@ class CoverageBuilder(Builder):
             op.close()
 
     def build_py_coverage(self):
-        for mod_name in self.env.modules:
+        objects = self.env.domaindata['py']['objects']
+        modules = self.env.domaindata['py']['modules']
+
+        for mod_name in modules:
             ignore = False
             for exp in self.mod_ignorexps:
                 if exp.match(mod_name):
@@ -129,7 +132,8 @@ class CoverageBuilder(Builder):
             try:
                 mod = __import__(mod_name, fromlist=['foo'])
             except ImportError, err:
-                self.warn('module %s could not be imported: %s' % (mod_name, err))
+                self.warn('module %s could not be imported: %s' %
+                          (mod_name, err))
                 self.py_undoc[mod_name] = {'error': err}
                 continue
 
@@ -151,7 +155,7 @@ class CoverageBuilder(Builder):
                 full_name = '%s.%s' % (mod_name, name)
 
                 if inspect.isfunction(obj):
-                    if full_name not in self.env.descrefs:
+                    if full_name not in objects:
                         for exp in self.fun_ignorexps:
                             if exp.match(name):
                                 break
@@ -162,20 +166,21 @@ class CoverageBuilder(Builder):
                         if exp.match(name):
                             break
                     else:
-                        if full_name not in self.env.descrefs:
+                        if full_name not in objects:
                             # not documented at all
                             classes[name] = []
                             continue
 
                         attrs = []
 
-                        for attr_name, attr in inspect.getmembers(obj, inspect.ismethod):
+                        for attr_name, attr in inspect.getmembers(
+                               obj, inspect.ismethod):
                             if attr_name[0] == '_':
                                 # starts with an underscore, ignore it
                                 continue
 
                             full_attr_name = '%s.%s' % (full_name, attr_name)
-                            if full_attr_name not in self.env.descrefs:
+                            if full_attr_name not in objects:
                                 attrs.append(attr_name)
 
                         if attrs:
@@ -216,8 +221,9 @@ class CoverageBuilder(Builder):
                                 op.writelines('   - %s\n' % x for x in methods)
                         op.write('\n')
 
-            write_header(op, 'Modules that failed to import')
-            op.writelines(' * %s -- %s\n' % x for x in failed)
+            if failed:
+                write_header(op, 'Modules that failed to import')
+                op.writelines(' * %s -- %s\n' % x for x in failed)
         finally:
             op.close()
 
@@ -239,4 +245,3 @@ def setup(app):
     app.add_config_value('coverage_c_path', [], False)
     app.add_config_value('coverage_c_regexes', {}, False)
     app.add_config_value('coverage_ignore_c_items', {}, False)
-
