@@ -6,16 +6,19 @@
     Test the sphinx.config.Config class and its handling in the
     Application class.
 
-    :copyright: 2008 by Georg Brandl.
-    :license: BSD.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 from util import *
 
-from sphinx.application import ExtensionError
+import sphinx
+from sphinx.config import Config
+from sphinx.errors import ExtensionError, ConfigError, VersionRequirementError
 
 
-@with_app(confoverrides={'master_doc': 'master', 'nonexisting_value': 'True'})
+@with_app(confoverrides={'master_doc': 'master', 'nonexisting_value': 'True',
+                         'latex_elements.docclass': 'scrartcl'})
 def test_core_config(app):
     cfg = app.config
 
@@ -26,15 +29,16 @@ def test_core_config(app):
 
     # overrides
     assert cfg.master_doc == 'master'
+    assert cfg.latex_elements['docclass'] == 'scrartcl'
 
     # simple default values
-    assert 'exclude_dirs' not in cfg.__dict__
-    assert cfg.exclude_dirs == []
-    assert cfg.show_authors == False
+    assert 'locale_dirs' not in cfg.__dict__
+    assert cfg.locale_dirs == []
+    assert cfg.trim_footnote_reference_space == False
 
     # complex default values
     assert 'html_title' not in cfg.__dict__
-    assert cfg.html_title == 'Sphinx <Tests> v0.4alpha1 documentation'
+    assert cfg.html_title == 'Sphinx <Tests> v0.6alpha1 documentation'
 
     # complex default values mustn't raise
     for valuename in cfg.config_values:
@@ -75,3 +79,24 @@ def test_extension_values(app):
                'html_title', 'x', True)
     raises_msg(ExtensionError, 'already present', app.add_config_value,
                'value_from_ext', 'x', True)
+
+
+@with_tempdir
+def test_errors_warnings(dir):
+    # test the error for syntax errors in the config file
+    write_file(dir / 'conf.py', 'project = \n')
+    raises_msg(ConfigError, 'conf.py', Config, dir, 'conf.py', {}, None)
+
+    # test the warning for bytestrings with non-ascii content
+    write_file(dir / 'conf.py', '# -*- coding: latin-1\nproject = "foo\xe4"\n')
+    cfg = Config(dir, 'conf.py', {}, None)
+    warned = [False]
+    def warn(msg):
+        warned[0] = True
+    cfg.check_unicode(warn)
+    assert warned[0]
+
+
+def test_needs_sphinx():
+    raises(VersionRequirementError, TestApp,
+           confoverrides={'needs_sphinx': '9.9'})
